==> funcoeszz_18.3.orig.tar.gz: funcoeszz-18.3/testador/zzdicportugues.sh <==
# Erros

$ zzdicportugues; echo $?
Uso: zzdicportugues palavra [def]
1
$ zzdicportugues foobar; echo $?
Palavra não encontrada
1
$


# Uso normal - acentuação

$ zzdicportugues maca
substantivo feminino Leito formado com duas hastes rígidas e um tecido flexível esticado ao meio e que serve para transportar feridos ou doentes: faltam macas para tantos feridos.
Cama de lona que serve para o descanso dos marinheiros embarcados.
Recipiente com quatro braços utilizado no transporte de mobília ou bagagens; padiola.
Saco de couro em que se leva roupa e que se amarra à garupa em viagem.
Ave doméstica do Peru.
Etimologia (origem da palavra maca). Do espanhol hamaca.

Maca é sinônimo de: leito, padiola
$

$ zzdicportugues maça
substantivo feminino Pedaço de madeira que possui uma de suas extremidades mais grossa.
Arma composta por um cabo com uma bola de ferro pesada e presa, geralmente por uma corrente, numa de suas extremidades.
Maço; tipo de instrumento que se assemelha ao pilão cilíndrico, usado por trabalhadores que calçam ruas com pedras.
Peça de madeira com o formato de uma garrafa usada por malabaristas.
Tipo de martelo que possui duas extremidades (cabeças).
Têxtil. Instrumento utilizado para bater ou maçar o linho, geralmente tem o formato de um pilão.
Culinária. Polpa feita com noz moscada.
Não confundir com: massa.
Etimologia (origem da palavra maça). Do latim matea; mattea; mateola.

Maça é sinônimo de: clava, tacape
$

$ zzdicportugues maçã
substantivo feminino Nome do fruto produzido pela macieira: adoro comer maçã!
[Por Extensão] O que se assemelha a uma maçã, em seu formato, aparência ou gosto; feito com esse fruto: caderno em forma de maçã; vinagre de maçã.
Maçaneta; a parte da frente, mais alta, de uma sela.
[Zoologia] Bezoar; tipo de pedra carnosa que, encontrada no estômago de certos animais, para algumas pessoas tem propriedade terapêutica.
[Gramática] Diminutivo irregular: maçanilha.
Maçã do rosto. A parte saliente do rosto que, situada abaixo dos olhos, é formada pelo osso malar.
Etimologia (origem da palavra maçã). Do latim matiana; mattiana.

Maçã é sinônimo de: maçaneta, bezoar
$

$ zzdicportugues louca
adjetivo Que deixou de ter razão; que se alienou; doida, maluca.
Que se opõe à razão; absurda: teoria louca.
Que não possui controle sobre os próprios comportamentos; descontrolada.
Sem sensatez, discernimento; insensata.
Completamente absorvida por uma intensa emoção: louca de saudade.
De teor ou caráter intenso; apaixonada: paixão louca.
De natureza anormal, fora do comum: projeto louco.
Cheia de raiva, de fúria; furiosa: ficou louca com a traição.
substantivo feminino Condição temporária de loucura; falta de sanidade mental.
Etimologia (origem da palavra louca). Feminino de louco, de origem controversa.

Louca é sinônimo de: doida, maluca, furiosa, louco
$

$ zzdicportugues louça
substantivo feminino Produtos e/ou objetos feitos em cerâmica, barro ou porcelana para servir refeições; esses utensílios: serviu o jantar com a louça antiga.
Produto de cerâmica esmaltada, usado de diversas maneiras, normalmente na confecção de objetos domésticos: bule de louça.
[Informal] Os utensílios domésticos usados na cozinha: preciso lavar a louça.
[Por Extensão] Xícara usada em bares e botequins; o café que se serve nessa xícara.
Desuso. Penico; objeto ou recipiente usado para urinar ou defecar.
Etimologia (origem da palavra louça). De origem questionável.

Louça é sinônimo de: loiça, penico
$

$ zzdicportugues louçã
adjetivo Enfeitado; coberto por adornos, enfeites.
[Figurado] Belo; repleto de brilho; bonito de se ver: pintura louçã.
[Pejorativo] Janota; que se veste exageradamente elegante.
[Gíria] Doidice; que se comporta loucamente.
Etimologia (origem da palavra louçã). Feminino de loução.

Louçã é sinônimo de: janota, belo
$


# Uso normal - verbos e conjugação

$ zzdicportugues compilar def | zzsqueeze -l
Classe gramatical: verbo transitivo direto
Tipo do verbo compilar: regular
Separação silábica: com-pi-lar

Possui 8 letras
Possui as vogais: a i o
Possui as consoantes: c l m p r
O verbo escrito ao contrário: ralipmoc
$

$ zzdicportugues falar
verbo regência múltipla Expressar-se através das palavras; dizer: falou mentiras; falou mentiras aos pais; quase nunca falava; não se falavam.
Dizer a verdade; revelar: o réu se recusava a falar ao juri.
Exercer influência: a honra deve falar mais alto que o interesse.
Iniciar um assunto; contar alguma coisa: falavam sobre o filme.
[Figurado] Ser expressivo ou compreensível; demonstrar: as ações falam sozinhas; olhos que falam.
Expressar-se numa outra língua: fala espanhol com perfeição.
verbo transitivo indireto Falar mal de; criticar: fala sempre da vizinha.
verbo pronominal Permanecer em contato com alguém: os pais não se falam.
substantivo masculino Ato de se expressar, de conversar: não ouço o falar do professor.
[Linguística] Variante de uma língua que depende de sua região; dialeto: o falar mineiro.
Etimologia (origem da palavra falar). Do latim fabulare.

Falar é sinônimo de: comunicar, conversar, discursar, exprimir, criticar, conversa, dialeto, dizer, revelar

Falar é o contrário de: calar, emudecer, silenciar
$

$ zzdicportugues comer
verbo transitivo direto Ingerir algum alimento, levando à boca e engolindo: ele não gosta de comer legumes; adorava comer tortas.
Roubar ou apropriar-se do não lhe pertence: os impostos comiam meu salário.
Deixar de ver; ocultar ou omitir: durante a leitura, comia palavras.
[Figurado] Gastar completamente; consumir: comeu a herança da filha.
[Figurado] Acreditar muito em: o delegado não comeu sua história.
[Figurado] Vulgar. Possuir sexualmente outra pessoa.
verbo pronominal Consumir-se por: comia-se de raiva!
verbo intransitivo Alimentar-se habitualmente: não como em restaurantes.
Provar pela primeira vez; experimentar: comer da maçã proibida.
[Figurado] Carcomer, roer, consumir: a ferrugem come o ferro.
[Figurado] Eliminar ou ganhar pedras em jogo de tabuleiro.
substantivo masculino Ação de comer; aquilo que se come ou ingere; alimento: o comer não lhe satisfaz.
Etimologia (origem da palavra comer). Do latim comedere.

Comer é sinônimo de: consumir, manducar, ingerir, ocultar, alimentar, roer, carcomer, manjar, papar
$

$ zzdicportugues comer def | sed '/Frases com o verbo comer/,/Possui/{/Possui/!d;}' | zzsqueeze -l
Classe gramatical: substantivo masculino, verbo intransitivo, verbo pronominal e verbo transitivo direto
Tipo do verbo comer: regular
Separação silábica: co-mer

Possui 5 letras
Possui as vogais: e o
Possui as consoantes: c m r
O verbo escrito ao contrário: remoc
$

==> funcoeszz_21.1.orig.tar.gz: funcoeszz-21.1/testador/zzdicportugues.sh <==
# Erros

$ zzdicportugues; echo $?
Uso: zzdicportugues palavra [def]
1
$ zzdicportugues foobar; echo $?
Palavra não encontrada
1
$


# Uso normal - acentuação

$ zzdicportugues maca
substantivo feminino Leito formado com duas hastes rígidas e um tecido flexível esticado ao meio e que serve para transportar feridos ou doentes: faltam macas para tantos feridos.
Cama de lona que serve para o descanso dos marinheiros embarcados.
Recipiente com quatro braços utilizado no transporte de mobília ou bagagens; padiola.
Saco de couro em que se leva roupa e que se amarra à garupa em viagem.
Ave doméstica do Peru.
Etimologia (origem da palavra maca). Do espanhol hamaca.

Maca é sinônimo de: leito, padiola
$

$ zzdicportugues maça
substantivo feminino Pedaço de madeira que possui uma de suas extremidades mais grossa.
Arma composta por um cabo com uma bola de ferro pesada e presa, geralmente por uma corrente, numa de suas extremidades.
Maço; tipo de instrumento que se assemelha ao pilão cilíndrico, usado por trabalhadores que calçam ruas com pedras.
Peça de madeira com o formato de uma garrafa usada por malabaristas.
Tipo de martelo que possui duas extremidades (cabeças).
Têxtil. Instrumento utilizado para bater ou maçar o linho, geralmente tem o formato de um pilão.
Culinária. Polpa feita com noz moscada.
Não confundir com: massa.
Etimologia (origem da palavra maça). Do latim matea; mattea; mateola.

Maça é sinônimo de: clava, tacape
$

$ zzdicportugues maçã
substantivo feminino Nome do fruto produzido pela macieira: adoro comer maçã!
[Por Extensão] O que se assemelha a uma maçã, em seu formato, aparência ou gosto; feito com esse fruto: caderno em forma de maçã; vinagre de maçã.
Maçaneta; a parte da frente, mais alta, de uma sela.
[Zoologia] Bezoar; tipo de pedra carnosa que, encontrada no estômago de certos animais, para algumas pessoas tem propriedade terapêutica.
[Gramática] Diminutivo irregular: maçanilha.
Maçã do rosto. A parte saliente do rosto que, situada abaixo dos olhos, é formada pelo osso malar.
Etimologia (origem da palavra maçã). Do latim matiana; mattiana.

Maçã é sinônimo de: maçaneta, bezoar
$

$ zzdicportugues louca
adjetivo Que deixou de ter razão; que se alienou; doida, maluca.
Que se opõe à razão; absurda: teoria louca.
Que não possui controle sobre os próprios comportamentos; descontrolada.
Sem sensatez, discernimento; insensata.
Completamente absorvida por uma intensa emoção: louca de saudade.
De teor ou caráter intenso; apaixonada: paixão louca.
De natureza anormal, fora do comum: projeto louco.
Cheia de raiva, de fúria; furiosa: ficou louca com a traição.
substantivo feminino Condição temporária de loucura; falta de sanidade mental.
Etimologia (origem da palavra louca). Feminino de louco, de origem controversa.

Louca é sinônimo de: doida, maluca, furiosa, louco, insensata, apaixonada
$

$ zzdicportugues louça
substantivo feminino Produtos e/ou objetos feitos em cerâmica, barro ou porcelana para servir refeições; esses utensílios: serviu o jantar com a louça antiga.
Produto de cerâmica esmaltada, usado de diversas maneiras, normalmente na confecção de objetos domésticos: bule de louça.
[Informal] Os utensílios domésticos usados na cozinha: preciso lavar a louça.
[Por Extensão] Xícara usada em bares e botequins; o café que se serve nessa xícara.
Desuso. Penico; objeto ou recipiente usado para urinar ou defecar.
Etimologia (origem da palavra louça). De origem questionável.

Louça é sinônimo de: loiça, penico
$

$ zzdicportugues louçã
adjetivo Enfeitado; coberto por adornos, enfeites.
[Figurado] Belo; repleto de brilho; bonito de se ver: pintura louçã.
[Pejorativo] Janota; que se veste exageradamente elegante.
[Gíria] Doidice; que se comporta loucamente.
Etimologia (origem da palavra louçã). Feminino de loução.

Louçã é sinônimo de: janota, belo
$


# Uso normal - verbos e conjugação

$ zzdicportugues compilar def | zzsqueeze -l
Classe gramatical: verbo transitivo direto
Tipo do verbo compilar: regular
Separação silábica: com-pi-lar

Possui 8 letras
Possui as vogais: a i o
Possui as consoantes: c l m p r
O verbo escrito ao contrário: ralipmoc
$

$ zzdicportugues falar
verbo regência múltipla Expressar-se através das palavras; dizer: falou mentiras; falou mentiras aos pais; quase nunca falava; não se falavam.
Dizer a verdade; revelar: o réu se recusava a falar ao juri.
Exercer influência: a honra deve falar mais alto que o interesse.
Iniciar um assunto; contar alguma coisa: falavam sobre o filme.
[Figurado] Ser expressivo ou compreensível; demonstrar: as ações falam sozinhas; olhos que falam.
Expressar-se numa outra língua: fala espanhol com perfeição.
verbo transitivo indireto Falar mal de; criticar: fala sempre da vizinha.
verbo pronominal Permanecer em contato com alguém: os pais não se falam.
substantivo masculino Ato de se expressar, de conversar: não ouço o falar do professor.
[Linguística] Variante de uma língua que depende de sua região; dialeto: o falar mineiro.
Etimologia (origem da palavra falar). Do latim fabulare.

Falar é sinônimo de: comunicar, conversar, discursar, exprimir, criticar, conversa, dialeto, dizer, revelar

Falar é o contrário de: calar, emudecer, silenciar
$

$ zzdicportugues comer
verbo transitivo direto Ingerir algum alimento, levando à boca e engolindo: ele não gosta de comer legumes; adorava comer tortas.
Roubar ou apropriar-se do não lhe pertence: os impostos comiam meu salário.
Deixar de ver; ocultar ou omitir: durante a leitura, comia palavras.
[Figurado] Gastar completamente; consumir: comeu a herança da filha.
[Figurado] Acreditar muito em: o delegado não comeu sua história.
[Figurado] Vulgar. Possuir sexualmente outra pessoa.
verbo pronominal Consumir-se por: comia-se de raiva!
verbo intransitivo Alimentar-se habitualmente: não como em restaurantes.
Provar pela primeira vez; experimentar: comer da maçã proibida.
[Figurado] Carcomer, roer, consumir: a ferrugem come o ferro.
[Figurado] Eliminar ou ganhar pedras em jogo de tabuleiro.
substantivo masculino Ação de comer; aquilo que se come ou ingere; alimento: o comer não lhe satisfaz.
Etimologia (origem da palavra comer). Do latim comedere.

Comer é sinônimo de: consumir, manducar, ingerir, ocultar, alimentar, roer, carcomer, manjar, papar
$

$ zzdicportugues comer def | sed '/Frases com o verbo comer/,/Possui/{/Possui/!d;}' | zzsqueeze -l
Classe gramatical: substantivo masculino, verbo intransitivo, verbo pronominal e verbo transitivo direto
Tipo do verbo comer: regular
Separação silábica: co-mer

Possui 5 letras
Possui as vogais: e o
Possui as consoantes: c m r
O verbo escrito ao contrário: remoc
$
